% This file contains the commands for solving the case of J=20 for the
% paper "Sticky Housing, Limited Participation, and the Real Effects of Monetary Policy"

% NOTE: YOU MUST HAVE INSTALLED THE DYNARE SOFTWARE PACKAGE TO USE THIS
% PROGRAM

% Declare the endogenous variables
var M0 M1 M2 M3 M4 M5 M6 M7 M8 M9 M10 M11 M12 M13 M14 M15 M16 M17 M18 M19
Ms
C0 C1 C2 C3 C4 C5 C6 C7 C8 C9 C10 C11 C12 C13 C14 C15 C16 C17 C18 C19 
Cs 
L0 L1 L2 L3 L4 L5 L6 L7 L8 L9 L10 L11 L12 L13 L14 L15 L16 L17 L18 L19 
H0 F R Rshort M C L bgov P rreal rrealmortg Resinv;

% Variable definitions
% Mj = nominal balances of home buyer j
% Cj = real consumption of home buyer j
% Lj = labor supply of home buyer j
% L = aggregate labor / output
% H0 = housing stock
% F = mortgage payment factor
% Rshort = nominal short rate
% P = price level
% Cs = consumption of lender
% Ms = nominal balances of a lender

% Declare the exogenous variable
varexo epsM;

% Declare the parameters 
parameters theta rhoR sigM beta eta etaM0 etaM1 delta J Lss Ljss omega1h omega1s gamma vel epsilon piss Cshare 
bss Cjss Hss Csss Css Qjss_Pss Qss_Pss Qsss_Pss omega1h omega1s Fss Rss;

% Parameters values and steady state ratios
rhoR = 0.8;
beta = 0.99;
theta = 0;
eta=8;
etaM0=1;
etaM1=1;
J=20;
epsilon=0.7;
Lss=0.2;
Ljss=Lss/epsilon;
piss=1.01;
Cshare=2/3;
delta=0.05;
vel=10;
Fss=1/(1+beta+beta^2+beta^3+beta^4+beta^5+beta^6+beta^7+beta^8+beta^9+beta^10+...
beta^11+beta^12+beta^13+beta^14+beta^15+beta^16+beta^17+beta^18+beta^(J-1));
Cjss=Cshare*Ljss/(1+Cshare/vel*(1-1/piss));
Hss=(Ljss+Cjss/vel*(1/piss-1)-Cjss)/(delta*Fss);
Csss=(Lss-Cjss*epsilon-delta*Hss*(epsilon/J))/(1-epsilon);
gamma=(Cjss/Hss)^(theta-1)*Fss*(1-beta^J*(1-delta)*Fss);
Qjss_Pss=Cjss/vel;
Qsss_Pss=Csss/vel;
Rss=piss/beta;
Qss_Pss=(epsilon*Qjss_Pss+ (1-epsilon)*Qsss_Pss);
Css=epsilon*Cjss+(1-epsilon)*Csss;
omega1h=(1-beta/piss)*Cjss^(theta-1)*(gamma*Hss^theta+Cjss^theta)^(-1)*(Qjss_Pss)^etaM0;
%omega1h=(1-beta)/Cjss*Qjss_Pss^etaM0;
omega1s=(1-beta/piss)/Csss*Qsss_Pss^etaM1;

sigM = 0.01/(100*0.001160907500056);
%sigM=0.01;

bss=-Qss_Pss*(1-1/piss)/(1-Rss/piss);



% Declare the model
model(linear);
# b1 = (gamma*Hss^theta+Cjss^theta)^(-1);
# b2 = -theta/(gamma*Hss^theta+Cjss^theta);
# b3 = beta^J*Fss*(1-delta)*Cjss^(theta-1);
# b4 = ((gamma*Hss^theta + Cjss^theta)^(-1)*Cjss^(theta-1))^(-1);
(gamma*Hss^(theta-1)/Fss+b3)^(-1)*(b3*Cjss^(theta-1)*F(+20)-b1*b3*theta*gamma*Hss^theta*H0(+20)+
b1*(theta-1-b1*theta*Cjss^theta)*C0(+20))=
F+(Fss*(theta-1-b1*theta*Cjss^theta)+(gamma*Hss^(theta-1)/Fss+b3)^(-1)*b1*gamma*theta*Hss^(theta-1)*Cjss^theta)*(
C0+beta*C1(+1)+beta^2*C2(+2)+beta^3*C3(+3)+beta^4*C4(+4)+beta^5*C5(+5)+beta^6*C6(+6)+beta^7*C7(+7)+beta^8*C8(+8)+
beta^9*C9(+9)+beta^10*C10(+10)+beta^11*C11(+11)+beta^12*C12(+12)+beta^13*C13(+13)+beta^14*C14(+14)+beta^15*C15(+15)+
beta^16*C16(+16)+beta^17*C17(+17)+beta^18*C18(+18)+beta^(J-1)*C19(+19))-
(b1*gamma*theta*Hss^theta+(gamma*Hss^(theta-1)+b3*Fss)^(-1)*
(gamma*(theta-1)*Hss^(theta-1)-b1*gamma^2*theta*Hss^(2*theta-1)))*H0;
b2*(gamma*Hss^theta*H0 + Cjss^theta*C0) + (theta-1)*C0 = eta*(Ljss/(1-Ljss))*L0;
b2*(gamma*Hss^theta*H0(-1) + Cjss^theta*C1) + (theta-1)*C1 =eta*(Ljss/(1-Ljss))*L1;
b2*(gamma*Hss^theta*H0(-2) + Cjss^theta*C2) + (theta-1)*C2= eta*(Ljss/(1-Ljss))*L2;
b2*(gamma*Hss^theta*H0(-3) + Cjss^theta*C3) + (theta-1)*C3= eta*(Ljss/(1-Ljss))*L3;
b2*(gamma*Hss^theta*H0(-4) + Cjss^theta*C4) + (theta-1)*C4= eta*(Ljss/(1-Ljss))*L4;
b2*(gamma*Hss^theta*H0(-5) + Cjss^theta*C5) + (theta-1)*C5= eta*(Ljss/(1-Ljss))*L5;
b2*(gamma*Hss^theta*H0(-6) + Cjss^theta*C6) + (theta-1)*C6= eta*(Ljss/(1-Ljss))*L6;
b2*(gamma*Hss^theta*H0(-7) + Cjss^theta*C7) + (theta-1)*C7= eta*(Ljss/(1-Ljss))*L7;
b2*(gamma*Hss^theta*H0(-8) + Cjss^theta*C8) + (theta-1)*C8= eta*(Ljss/(1-Ljss))*L8;
b2*(gamma*Hss^theta*H0(-9) + Cjss^theta*C9) + (theta-1)*C9= eta*(Ljss/(1-Ljss))*L9;
b2*(gamma*Hss^theta*H0(-10) + Cjss^theta*C10) + (theta-1)*C10= eta*(Ljss/(1-Ljss))*L10;
b2*(gamma*Hss^theta*H0(-11) + Cjss^theta*C11) + (theta-1)*C11= eta*(Ljss/(1-Ljss))*L11;
b2*(gamma*Hss^theta*H0(-12) + Cjss^theta*C12) + (theta-1)*C12= eta*(Ljss/(1-Ljss))*L12;
b2*(gamma*Hss^theta*H0(-13) + Cjss^theta*C13) + (theta-1)*C13= eta*(Ljss/(1-Ljss))*L13;
b2*(gamma*Hss^theta*H0(-14) + Cjss^theta*C14) + (theta-1)*C14= eta*(Ljss/(1-Ljss))*L14;
b2*(gamma*Hss^theta*H0(-15) + Cjss^theta*C15) + (theta-1)*C15= eta*(Ljss/(1-Ljss))*L15;
b2*(gamma*Hss^theta*H0(-16) + Cjss^theta*C16) + (theta-1)*C16= eta*(Ljss/(1-Ljss))*L16;
b2*(gamma*Hss^theta*H0(-17) + Cjss^theta*C17) + (theta-1)*C17= eta*(Ljss/(1-Ljss))*L17;
b2*(gamma*Hss^theta*H0(-18) + Cjss^theta*C18) + (theta-1)*C18= eta*(Ljss/(1-Ljss))*L18;
b2*(gamma*Hss^theta*H0(-19) + Cjss^theta*C19) + (theta-1)*C19= eta*(Ljss/(1-Ljss))*L19;
b2*(gamma*Hss^theta*H0 + Cjss^theta*C0) + (theta-1)*C0 = b4*omega1h*(Qjss_Pss)^(-etaM0)*etaM0*(-M0+P) + 
beta/piss*b2*(gamma*Hss^theta*H0 + Cjss^theta*C1(+1)) + beta*(theta-1)*C1(+1) + beta*(-P(+1)+P);
b2*(gamma*Hss^theta*H0(-1) + Cjss^theta*C1) + (theta-1)*C1 = b4*omega1h*(Qjss_Pss)^(-etaM0)*etaM0*(-M1+P) + 
beta/piss*b2*(gamma*Hss^theta*H0(-1) + Cjss^theta*C2(+1)) + beta*(theta-1)*C2(+1) + beta*(-P(+1)+P);
b2*(gamma*Hss^theta*H0(-2) + Cjss^theta*C2) + (theta-1)*C2 = b4*omega1h*(Qjss_Pss)^(-etaM0)*etaM0*(-M2+P) + 
beta/piss*b2*(gamma*Hss^theta*H0(-2) + Cjss^theta*C3(+1)) + beta*(theta-1)*C3(+1) + beta*(-P(+1)+P);
b2*(gamma*Hss^theta*H0(-3) + Cjss^theta*C3) + (theta-1)*C3 = b4*omega1h*(Qjss_Pss)^(-etaM0)*etaM0*(-M3+P) + 
beta/piss*b2*(gamma*Hss^theta*H0(-3) + Cjss^theta*C4(+1)) + beta*(theta-1)*C4(+1) + beta*(-P(+1)+P);
b2*(gamma*Hss^theta*H0(-4) + Cjss^theta*C4) + (theta-1)*C4 = b4*omega1h*(Qjss_Pss)^(-etaM0)*etaM0*(-M4+P) + 
beta/piss*b2*(gamma*Hss^theta*H0(-4) + Cjss^theta*C5(+1)) + beta*(theta-1)*C5(+1) + beta*(-P(+1)+P);
b2*(gamma*Hss^theta*H0(-5) + Cjss^theta*C5) + (theta-1)*C5 = b4*omega1h*(Qjss_Pss)^(-etaM0)*etaM0*(-M5+P) + 
beta/piss*b2*(gamma*Hss^theta*H0(-5) + Cjss^theta*C6(+1)) + beta*(theta-1)*C6(+1) + beta*(-P(+1)+P);
b2*(gamma*Hss^theta*H0(-6) + Cjss^theta*C6) + (theta-1)*C6 = b4*omega1h*(Qjss_Pss)^(-etaM0)*etaM0*(-M6+P) + 
beta/piss*b2*(gamma*Hss^theta*H0(-6) + Cjss^theta*C7(+1)) + beta*(theta-1)*C7(+1) + beta*(-P(+1)+P);
b2*(gamma*Hss^theta*H0(-7) + Cjss^theta*C7) + (theta-1)*C7 = b4*omega1h*(Qjss_Pss)^(-etaM0)*etaM0*(-M7+P) + 
beta/piss*b2*(gamma*Hss^theta*H0(-7) + Cjss^theta*C8(+1)) + beta*(theta-1)*C8(+1) + beta*(-P(+1)+P);
b2*(gamma*Hss^theta*H0(-8) + Cjss^theta*C8) + (theta-1)*C8 = b4*omega1h*(Qjss_Pss)^(-etaM0)*etaM0*(-M8+P) + 
beta/piss*b2*(gamma*Hss^theta*H0(-8) + Cjss^theta*C9(+1)) + beta*(theta-1)*C9(+1) + beta*(-P(+1)+P);
b2*(gamma*Hss^theta*H0(-9) + Cjss^theta*C9) + (theta-1)*C9 = b4*omega1h*(Qjss_Pss)^(-etaM0)*etaM0*(-M9+P) + 
beta/piss*b2*(gamma*Hss^theta*H0(-9) + Cjss^theta*C10(+1)) + beta*(theta-1)*C10(+1) + beta*(-P(+1)+P);
b2*(gamma*Hss^theta*H0(-10) + Cjss^theta*C10) + (theta-1)*C10 = b4*omega1h*(Qjss_Pss)^(-etaM0)*etaM0*(-M10+P) + 
beta/piss*b2*(gamma*Hss^theta*H0(-10) + Cjss^theta*C11(+1)) + beta*(theta-1)*C11(+1) + beta*(-P(+1)+P);
b2*(gamma*Hss^theta*H0(-11) + Cjss^theta*C11) + (theta-1)*C11 = b4*omega1h*(Qjss_Pss)^(-etaM0)*etaM0*(-M11+P) + 
beta/piss*b2*(gamma*Hss^theta*H0(-11) + Cjss^theta*C12(+1)) + beta*(theta-1)*C12(+1) + beta*(-P(+1)+P);
b2*(gamma*Hss^theta*H0(-12) + Cjss^theta*C12) + (theta-1)*C12 = b4*omega1h*(Qjss_Pss)^(-etaM0)*etaM0*(-M12+P) + 
beta/piss*b2*(gamma*Hss^theta*H0(-12) + Cjss^theta*C13(+1)) + beta*(theta-1)*C13(+1) + beta*(-P(+1)+P);
b2*(gamma*Hss^theta*H0(-13) + Cjss^theta*C13) + (theta-1)*C13 = b4*omega1h*(Qjss_Pss)^(-etaM0)*etaM0*(-M13+P) + 
beta/piss*b2*(gamma*Hss^theta*H0(-13) + Cjss^theta*C14(+1)) + beta*(theta-1)*C14(+1) + beta*(-P(+1)+P);
b2*(gamma*Hss^theta*H0(-14) + Cjss^theta*C14) + (theta-1)*C14 = b4*omega1h*(Qjss_Pss)^(-etaM0)*etaM0*(-M14+P) + 
beta/piss*b2*(gamma*Hss^theta*H0(-14) + Cjss^theta*C15(+1)) + beta*(theta-1)*C15(+1) + beta*(-P(+1)+P);
b2*(gamma*Hss^theta*H0(-15) + Cjss^theta*C15) + (theta-1)*C15 = b4*omega1h*(Qjss_Pss)^(-etaM0)*etaM0*(-M15+P) + 
beta/piss*b2*(gamma*Hss^theta*H0(-15) + Cjss^theta*C16(+1)) + beta*(theta-1)*C16(+1) + beta*(-P(+1)+P);
b2*(gamma*Hss^theta*H0(-16) + Cjss^theta*C16) + (theta-1)*C16 = b4*omega1h*(Qjss_Pss)^(-etaM0)*etaM0*(-M16+P) + 
beta/piss*b2*(gamma*Hss^theta*H0(-16) + Cjss^theta*C17(+1)) + beta*(theta-1)*C17(+1) + beta*(-P(+1)+P);
b2*(gamma*Hss^theta*H0(-17) + Cjss^theta*C17) + (theta-1)*C17 = b4*omega1h*(Qjss_Pss)^(-etaM0)*etaM0*(-M17+P) + 
beta/piss*b2*(gamma*Hss^theta*H0(-17) + Cjss^theta*C18(+1)) + beta*(theta-1)*C18(+1) + beta*(-P(+1)+P);
b2*(gamma*Hss^theta*H0(-18) + Cjss^theta*C18) + (theta-1)*C18 = b4*omega1h*(Qjss_Pss)^(-etaM0)*etaM0*(-M18+P) + 
beta/piss*b2*(gamma*Hss^theta*H0(-18) + Cjss^theta*C19(+1)) + beta*(theta-1)*C19(+1) + beta*(-P(+1)+P);
b2*(gamma*Hss^theta*H0(-19) + Cjss^theta*C19) + (theta-1)*C19 = b4*omega1h*(Qjss_Pss)^(-etaM0)*etaM0*(-M19+P) + 
beta/piss*b2*(gamma*Hss^theta*H0(+1) + Cjss^theta*C0(+1)) + beta*(theta-1)*C0(+1) + beta*(-P(+1)+P);
Cjss*C0 = Ljss*L0+(Qjss_Pss)*(M19(-1)-M0) - Hss*Fss*(H0-(1-delta)*H0(-20)+delta*F);
Cjss*C1 = Ljss*L1+(Qjss_Pss)*(M0(-1)-M1) - Hss*Fss*(H0(-1)-(1-delta)*H0(-21)+delta*F(-1));
Cjss*C2 = Ljss*L2+(Qjss_Pss)*(M1(-1)-M2) - Hss*Fss*(H0(-2)-(1-delta)*H0(-22)+delta*F(-2));
Cjss*C3 = Ljss*L3+(Qjss_Pss)*(M2(-1)-M3) - Hss*Fss*(H0(-3)-(1-delta)*H0(-23)+delta*F(-3));
Cjss*C4 = Ljss*L4+(Qjss_Pss)*(M3(-1)-M4) - Hss*Fss*(H0(-4)-(1-delta)*H0(-24)+delta*F(-4));
Cjss*C5 = Ljss*L5+(Qjss_Pss)*(M4(-1)-M5) - Hss*Fss*(H0(-5)-(1-delta)*H0(-25)+delta*F(-5));
Cjss*C6 = Ljss*L6+(Qjss_Pss)*(M5(-1)-M6) - Hss*Fss*(H0(-6)-(1-delta)*H0(-26)+delta*F(-6));
Cjss*C7 = Ljss*L7+(Qjss_Pss)*(M6(-1)-M7) - Hss*Fss*(H0(-7)-(1-delta)*H0(-27)+delta*F(-7));
Cjss*C8 = Ljss*L8+(Qjss_Pss)*(M7(-1)-M8) - Hss*Fss*(H0(-8)-(1-delta)*H0(-28)+delta*F(-8));
Cjss*C9 = Ljss*L9+(Qjss_Pss)*(M8(-1)-M9) - Hss*Fss*(H0(-9)-(1-delta)*H0(-29)+delta*F(-9));
Cjss*C10 = Ljss*L10+(Qjss_Pss)*(M9(-1)-M10) - Hss*Fss*(H0(-10)-(1-delta)*H0(-30)+delta*F(-10));
Cjss*C11 = Ljss*L11+(Qjss_Pss)*(M10(-1)-M11) - Hss*Fss*(H0(-11)-(1-delta)*H0(-31)+delta*F(-11));
Cjss*C12 = Ljss*L12+(Qjss_Pss)*(M11(-1)-M12) - Hss*Fss*(H0(-12)-(1-delta)*H0(-32)+delta*F(-12));
Cjss*C13 = Ljss*L13+(Qjss_Pss)*(M12(-1)-M13) - Hss*Fss*(H0(-13)-(1-delta)*H0(-33)+delta*F(-13));
Cjss*C14 = Ljss*L14+(Qjss_Pss)*(M13(-1)-M14) - Hss*Fss*(H0(-14)-(1-delta)*H0(-34)+delta*F(-14));
Cjss*C15 = Ljss*L15+(Qjss_Pss)*(M14(-1)-M15) - Hss*Fss*(H0(-15)-(1-delta)*H0(-35)+delta*F(-15));
Cjss*C16 = Ljss*L16+(Qjss_Pss)*(M15(-1)-M16) - Hss*Fss*(H0(-16)-(1-delta)*H0(-36)+delta*F(-16));
Cjss*C17 = Ljss*L17+(Qjss_Pss)*(M16(-1)-M17) - Hss*Fss*(H0(-17)-(1-delta)*H0(-37)+delta*F(-17));
Cjss*C18 = Ljss*L18+(Qjss_Pss)*(M17(-1)-M18) - Hss*Fss*(H0(-18)-(1-delta)*H0(-38)+delta*F(-18));
Cjss*C19 = Ljss*L19+(Qjss_Pss)*(M18(-1)-M19) - Hss*Fss*(H0(-19)-(1-delta)*H0(-39)+delta*F(-19));
-Cs = omega1s*Csss*(Qsss_Pss)^(-etaM1)*etaM1*(-Ms+P)-beta/piss*Cs(+1)-beta/piss*(P(+1)-P);
-Cs = -Cs(+1)+Rshort-P(+1)+P;
-Cs = Fss*(F - Cs +beta*(F-Cs(+1)) + beta^2*(F-Cs(+2))+beta^3*(F-Cs(+3))+beta^4*(F-Cs(+4))+beta^5*(F-Cs(+5))+
beta^6*(F-Cs(+6))+beta^7*(F-Cs(+7))+beta^8*(F-Cs(+8))+beta^9*(F-Cs(+9))+beta^10*(F-Cs(+10))+beta^11*(F-Cs(+11))+
beta^12*(F-Cs(+12))+beta^13*(F-Cs(+13))+beta^14*(F-Cs(+14))+beta^15*(F-Cs(+15))+beta^16*(F-Cs(+16))+beta^17*(F-Cs(+17))+
beta^18*(F-Cs(+18))+beta^19*(F-Cs(+19)));
L=(epsilon/J)*(Ljss/Lss)*(L0+L1+L2+L3+L4+L5+L6+L7+L8+L9+L10+L11+L12+L13+L14+L15+L16+L17+L18+L19);
L = (epsilon/J)*Cjss*(C0+C1+C2+C3+C4+C5+C6+C7+C8+C9+C10+C11+C12+C13+C14+C15+C16+C17+C18+C19)+ 
(1-epsilon)*Csss*Cs + (epsilon/J)*Hss*(H0-(1-delta)*H0(-20));
M = (epsilon/J)*(Qjss_Pss/Qss_Pss)*(M0+M1+M2+M3+M4+M5+M6+M7+M8+M9+M10+M11+M12+M13+M14+M15+M16+M17+M18+M19)+
(1-epsilon)*(Qsss_Pss/Qss_Pss)*Ms; 
Rshort=rhoR*Rshort(-1)+epsM;
rreal = Rshort - P(+1)+P;
M=M(-1)-(bss/Qss_Pss)*bgov+(Rss*bss/(Qss_Pss))*Rshort+(Rss*bss/(Qss_Pss))*bgov(-1);
C = (epsilon/J)*(Cjss/Css)*(C0+C1+C2+C3+C4+C5+C6+C7+C8+C9+C10+C11+C12+C13+C14+C15+C16+C17+C18+C19)+
(1-epsilon)*(Csss/Css)*Cs;
F = (1/(1-beta) + (J-1) - J/(1-beta^J))*R;
rrealmortg = R;
Resinv=H0/delta-(1-delta)/delta*H0(-20);
end;

% Declare the variances of the shock processes
shocks;
var epsM; stderr sigM;
end;

check;

steady;

stoch_simul(linear,irf=40,nomoments) C0 M0 L0 C1 M1 L1 C2 M2 L2 C3 M3 L3 C4 M4 L4 C5 M5 L5 C6 M6 L6 C7 M7 L7 C8 M8 L8 
C11 M11 L11 C15 M15 L15 C19 M19 L19 Cs Ms H0 C L R Rshort rreal bgov F M P Resinv;

% Renaming IRFs
C_J20=C_epsM;
Cs_J20=Cs_epsM;
H0_J20=H0_epsM;
L_J20=L_epsM;
R_J20=R_epsM;
rreal_J20=rreal_epsM;
P_J20=P_epsM;
M_J20=M_epsM;
Resinv_J20=Resinv_epsM;
bgov_J20=bgov_epsM;
Ms_J20=Ms_epsM;

save IRFS_J20_10bp C_J20 Cs_J20 H0_J20 L_J20 R_J20 rreal_J20 P_J20 M_J20 Resinv_J20 bgov_J20 Ms_J20;